@@ -14,7 +14,6 @@
 
 from __future__ import annotations
 
-import copy
 import datetime
 import abc
 import random
@@ -202,10 +201,6 @@ class BuildJobResultFunc(NodeFunction[_config.JobResult]):
             obj_def = _ctx_lookup(node_id, ctx)
             job_result.results[obj_id] = obj_def
 
-        for obj_id, node_id in self.node.attrs.items():
-            attrs = _ctx_lookup(node_id, ctx)
-            job_result.attrs[obj_id] = attrs
-
         for bundle_id in self.node.bundles:
             bundle = _ctx_lookup(bundle_id, ctx)
             job_result.results.update(bundle.items())
@@ -480,6 +475,18 @@ class SaveDataFunc(NodeFunction[None], _LoadSaveDataFunc):
             storage_options=options, overwrite=False)
 
 
+def _model_def_for_import(import_details: meta.ImportModelJob):
+
+    return meta.ModelDefinition(
+        language=import_details.language,
+        repository=import_details.repository,
+        packageGroup=import_details.packageGroup,
+        package=import_details.package,
+        version=import_details.version,
+        entryPoint=import_details.entryPoint,
+        path=import_details.path)
+
+
 class ImportModelFunc(NodeFunction[meta.ObjectDefinition]):
 
     def __init__(self, node: ImportModelNode, models: _models.ModelLoader):
@@ -490,43 +497,14 @@ class ImportModelFunc(NodeFunction[meta.ObjectDefinition]):
 
     def _execute(self, ctx: NodeContext) -> meta.ObjectDefinition:
 
-        stub_model_def = meta.ModelDefinition(
-            language=self.node.import_details.language,
-            repository=self.node.import_details.repository,
-            path=self.node.import_details.path,
-            entryPoint=self.node.import_details.entryPoint,
-            version=self.node.import_details.version)
+        model_stub = _model_def_for_import(self.node.import_details)
 
-        model_class = self._models.load_model_class(self.node.model_scope, stub_model_def)
-        model_scan = self._models.scan_model(model_class)
-
-        model_def = copy.copy(stub_model_def)
-        model_def.parameters = model_scan.parameters
-        model_def.inputs = model_scan.inputs
-        model_def.outputs = model_scan.outputs
+        model_class = self._models.load_model_class(self.node.model_scope, model_stub)
+        model_def = self._models.scan_model(model_stub, model_class)
 
         return meta.ObjectDefinition(meta.ObjectType.MODEL, model=model_def)
 
 
-class ImportAttrsFunc(NodeFunction[_config.TagUpdateList]):
-
-    def __init__(self, node: ImportAttrsNode, models: _models.ModelLoader):
-        self.node = node
-        self._models = models
-
-    def _execute(self, ctx: NodeContext) -> _config.TagUpdateList:
-
-        stub_model_def = meta.ModelDefinition(
-            language=self.node.import_details.language,
-            repository=self.node.import_details.repository,
-            path=self.node.import_details.path,
-            entryPoint=self.node.import_details.entryPoint,
-            version=self.node.import_details.version)
-
-        model_class = self._models.load_model_class(self.node.model_scope, stub_model_def)
-        return self._models.scan_model_attrs(model_class)
-
-
 class RunModelFunc(NodeFunction[Bundle[_data.DataView]]):
 
     def __init__(self, node: RunModelNode, model_class: _api.TracModel.__class__):
@@ -643,9 +621,6 @@ class FunctionResolver:
     def resolve_import_model_node(self, node: ImportModelNode):
         return ImportModelFunc(node, self._models)
 
-    def resolve_import_attrs_node(self, node: ImportAttrsNode):
-        return ImportAttrsFunc(node, self._models)
-
     def resolve_run_model_node(self, node: RunModelNode) -> NodeFunction:
 
         model_class = self._models.load_model_class(node.model_scope, node.model_def)
@@ -676,6 +651,5 @@ class FunctionResolver:
         SaveDataNode: resolve_save_data,
         DynamicDataSpecNode: resolve_dynamic_data_spec,
         RunModelNode: resolve_run_model_node,
-        ImportModelNode: resolve_import_model_node,
-        ImportAttrsNode: resolve_import_attrs_node
+        ImportModelNode: resolve_import_model_node
     }
